# xwquery Fixes Complete (absorbed)

See [docs/_archive/XWQUERY_FIXES_COMPLETE.md](../_archive/XWQUERY_FIXES_COMPLETE.md). Current status: [REF_22_PROJECT.md](../REF_22_PROJECT.md), [REF_35_REVIEW.md](../REF_35_REVIEW.md).
